/* wptHotkey.h - Hotkey registration
 *	Copyright (C) 2001-2006 Timo Schulz
 *
 * This file is part of WinPT.
 *
 * WinPT is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation; either version 2 
 * of the License, or (at your option) any later version.
 *  
 * WinPT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with WinPT; if not, write to the Free Software Foundation, 
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 */
#ifndef WPT_HOTKEY_H
#define WPT_HOTKEY_H

/* Hotkey IDs. */
enum hotkey_id_t {
    WPT_CLIP_ENCRYPT_ID	          = 0x3000,
    WPT_CLIP_DECRYPT_VERIFY_ID    = 0x3001,
    WPT_CLIP_SIGN_ID              = 0x3002,
    WPT_CLIP_SIGN_ENCRYPT_ID      = 0x3003,
    WPT_CURRWND_ENCRYPT_ID        = 0x4000,
    WPT_CURRWND_DECRYPT_VERIFY_ID = 0x4001,
    WPT_CURRWND_SIGN_ID           = 0x4002,
    WPT_CURRWND_SIGN_ENCRYPT_ID   = 0x4003,
    WPT_AGENT_FORGET_ID           = 0x5000,
};

/* Hotkey context. */
struct hotkey_s {
    const char *name;   /* name in the registry. */
    int enabled;	/* 1 = enabled. */
    int id;		/* valid ID (see above). */
    int alt_ctrl;	/* hotkey used with ALT+ */
    int alt_shift;	/* hotkey used with SHIFT+ */
    int key;		/* actual key code. */
};
typedef struct hotkey_s *hotkey_t;

extern hotkey_s wpt_hotkeys[];

const char * hotkeys_strerror (void);
int hotkeys_register (HWND wnd);
int hotkeys_unregister (HWND wnd);
int hotkey_register_single (HWND wnd, hotkey_t hk);
int hotkey_unregister_single (HWND wnd, hotkey_t hk);
void hotkey_disable (hotkey_t hk);
void hotkey_enable (hotkey_t hk, const char * key);

#endif /* WPT_HOTKEY_H */
